@@ -2,7 +2,7 @@ from collections import OrderedDict
 
 from django import forms
 from django.utils.functional import cached_property
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from . import app_settings
 from .helpers import get_foreign_keys
